rai\_toolbox.datasets.CIFAR10P1
===============================

.. currentmodule:: rai_toolbox.datasets

.. autoclass:: CIFAR10P1

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CIFAR10P1.__init__
   
   